"use strict";
/* eslint-disable @typescript-eslint/consistent-type-assertions */
/* eslint-disable @typescript-eslint/no-empty-function */
/* eslint-disable @typescript-eslint/no-unused-vars */
/* eslint-disable @typescript-eslint/no-namespace */
/* eslint-disable @typescript-eslint/no-explicit-any */
/*
 * This program and the accompanying materials are made available under the terms of the *
 * Eclipse Public License v2.0 which accompanies this distribution, and is available at *
 * https://www.eclipse.org/legal/epl-v20.html                                      *
 *                                                                                 *
 * SPDX-License-Identifier: EPL-2.0                                                *
 *                                                                                 *
 * Copyright Contributors to the Zowe Project.                                     *
 *                                                                                 *
 */
Object.defineProperty(exports, "__esModule", { value: true });
exports.env = exports.workspace = exports.EventEmitter = exports.TreeItemCollapsibleState = exports.TreeItem = exports.Disposable = exports.commands = exports.window = void 0;
// tslint:disable-next-line: no-namespace
var window;
(function (window) {
    /**
     * Show an information message to users. Optionally provide an array of items which will be presented as
     * clickable buttons.
     *
     * @param message The message to show.
     * @param items A set of items that will be rendered as actions in the message.
     * @return A thenable that resolves to the selected item or `undefined` when being dismissed.
     */
    function showInformationMessage(message, ...items) {
        return undefined;
    }
    window.showInformationMessage = showInformationMessage;
    function showErrorMessage(message, ...items) {
        return undefined;
    }
    window.showErrorMessage = showErrorMessage;
    /**
     * Creates a new [output channel](#OutputChannel) with the given name.
     *
     * @param name Human-readable string which will be used to represent the channel in the UI.
     */
    function createOutputChannel(name) {
        return {
            name,
            append: (value) => { },
            appendLine: (value) => { },
            clear: () => { },
            show: (column, preserveFocus) => { },
            hide: () => { },
            dispose: () => { },
        };
    }
    window.createOutputChannel = createOutputChannel;
})(window = exports.window || (exports.window = {}));
// tslint:disable-next-line: no-namespace
var commands;
(function (commands) {
    /**
     * Registers a command that can be invoked via a keyboard shortcut,
     * a menu item, an action, or directly.
     *
     * Registering a command with an existing command identifier twice
     * will cause an error.
     *
     * @param command A unique identifier for the command.
     * @param callback A command handler function.
     * @param thisArg The `this` context used when invoking the handler function.
     * @return Disposable which unregisters this command on disposal.
     */
    function registerCommand(command, callback, thisArg) {
        return undefined;
    }
    commands.registerCommand = registerCommand;
})(commands = exports.commands || (exports.commands = {}));
class Disposable {
    /**
     * Creates a new Disposable calling the provided function
     * on dispose.
     * @param callOnDispose Function that disposes something.
     */
    // tslint:disable-next-line: no-empty
    constructor() { }
}
exports.Disposable = Disposable;
// tslint:disable-next-line: max-classes-per-file
class TreeItem {
    /**
     * @param label A human-readable string describing this item
     * @param collapsibleState [TreeItemCollapsibleState](#TreeItemCollapsibleState) of the tree item.
     * Default is [TreeItemCollapsibleState.None](#TreeItemCollapsibleState.None)
     */
    constructor(label, collapsibleState) {
        this.label = label;
        this.collapsibleState = collapsibleState;
    }
}
exports.TreeItem = TreeItem;
/**
 * Collapsible state of the tree item
 */
var TreeItemCollapsibleState;
(function (TreeItemCollapsibleState) {
    /**
     * Determines an item can be neither collapsed nor expanded. Implies it has no children.
     */
    TreeItemCollapsibleState[TreeItemCollapsibleState["None"] = 0] = "None";
    /**
     * Determines an item is collapsed
     */
    TreeItemCollapsibleState[TreeItemCollapsibleState["Collapsed"] = 1] = "Collapsed";
    /**
     * Determines an item is expanded
     */
    TreeItemCollapsibleState[TreeItemCollapsibleState["Expanded"] = 2] = "Expanded";
})(TreeItemCollapsibleState = exports.TreeItemCollapsibleState || (exports.TreeItemCollapsibleState = {}));
/**
 * An event emitter can be used to create and manage an [event](#Event) for others
 * to subscribe to. One emitter always owns one event.
 *
 * Use this class if you want to provide event from within your extension, for instance
 * inside a [TextDocumentContentProvider](#TextDocumentContentProvider) or when providing
 * API to other extensions.
 */
// tslint:disable-next-line: max-classes-per-file
class EventEmitter {
    /**
     * Notify all subscribers of the [event](EventEmitter#event). Failure
     * of one or more listener will not fail this function call.
     *
     * @param data The event object.
     */
    // tslint:disable-next-line: no-empty
    fire(data) { }
}
exports.EventEmitter = EventEmitter;
/**
 * Namespace for dealing with the current workspace. A workspace is the representation
 * of the folder that has been opened. There is no workspace when just a file but not a
 * folder has been opened.
 *
 * The workspace offers support for [listening](#workspace.createFileSystemWatcher) to fs
 * events and for [finding](#workspace.findFiles) files. Both perform well and run _outside_
 * the editor-process so that they should be always used instead of nodejs-equivalents.
 */
// tslint:disable-next-line: no-namespace
var workspace;
(function (workspace) {
    function openTextDocument(fileName) { }
    workspace.openTextDocument = openTextDocument;
})(workspace = exports.workspace || (exports.workspace = {}));
/**
 * Namespace describing the environment the editor runs in.
 */
// tslint:disable-next-line: no-namespace
var env;
(function (env) {
    /**
     * The application name of the editor, like 'VS Code'.
     */
    env.appName = 'Visual Studio Code';
    /**
     * The system clipboard.
     */
    env.clipboard = {
        writeText() {
            return Promise.resolve();
        },
    };
})(env = exports.env || (exports.env = {}));
//# sourceMappingURL=vscode.js.map