"use strict";
/*
 * Copyright (c) 2020 Broadcom.
 * The term "Broadcom" refers to Broadcom Inc. and/or its subsidiaries.
 *
 * This program and the accompanying materials are made
 * available under the terms of the Eclipse Public License 2.0
 * which is available at https://www.eclipse.org/legal/epl-2.0/
 *
 * SPDX-License-Identifier: EPL-2.0
 *
 * Contributors:
 *   Broadcom, Inc. - initial API and implementation
 */
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
Object.defineProperty(exports, "__esModule", { value: true });
const vscode = require("vscode");
const endevor_for_zowe_cli_1 = require("@broadcom/endevor-for-zowe-cli");
const RetrieveElementWithDependencies_1 = require("../../../commands/RetrieveElementWithDependencies");
const globals_1 = require("../../../globals");
const Element_1 = require("../../../model/Element");
const Repository_1 = require("../../../model/Repository");
const RetrieveElementService_1 = require("../../../service/RetrieveElementService");
const EndevorNodes_1 = require("../../../ui/tree/EndevorNodes");
// Explicitly show NodeJS how to find VSCode (required for Jest)
process.vscode = vscode;
describe('Test function retrieveWithDependencies (retrieve element with dependencies)', () => {
    // Mock the workspace folder so it is selected/unselected, as needed
    const mockWorkspaceFolders = ['testFolder'];
    Object.defineProperty(vscode.workspace, 'workspaceFolders', {
        value: mockWorkspaceFolders,
    });
    // Mock vscode's progress function
    const mockWithProgress = jest.fn();
    Object.defineProperty(vscode, 'ProgressLocation', {
        value: { Notification: 15 },
    });
    Object.defineProperty(vscode.window, 'withProgress', {
        value: mockWithProgress,
    });
    // Mock the elements, nodes, and repo
    const mockRetrieveElement = jest.fn();
    const mockQueryACMComponents = jest.fn();
    const testRetrieveEltService = new RetrieveElementService_1.RetrieveElementService();
    Object.defineProperty(testRetrieveEltService, 'retrieveElement', {
        value: mockRetrieveElement,
    });
    Object.defineProperty(endevor_for_zowe_cli_1.QueryACMComponents, 'queryACMComponents', {
        value: mockQueryACMComponents,
    });
    const testRepo = new Repository_1.Repository('testRepo', 'https://example.com:1234', 'testUser', 'testPass', 'testRepo', 'testConnLabel');
    const testIElements = [
        {
            elmName: 'elmTest1',
            fullElmName: 'elmTest1',
            elmVVLL: '1100',
            envName: 'envTest',
            sysName: 'sysTest',
            sbsName: 'sbsTest',
            stgNum: '1',
            typeName: 'COBOL',
        },
        {
            elmName: 'elmTest2',
            fullElmName: 'elmTest2',
            elmVVLL: '1100',
            envName: 'envTest',
            sysName: 'sysTest',
            sbsName: 'sbsTest',
            stgNum: '1',
            typeName: 'COBOL',
        },
    ];
    const testDependencies = [
        {
            elmName: 'depTest1',
            envName: 'envTest',
            sysName: 'sysTest',
            sbsName: 'sbsTest',
            stgNumber: '1',
            typeName: 'COBOL',
            components: [testIElements[0]],
        },
    ];
    const testElements = [
        new Element_1.Element(testRepo, testIElements[0]),
        new Element_1.Element(testRepo, testIElements[1]),
    ];
    const qualifier1 = {
        element: testElements[0].elmName,
        env: 'envTest',
        stage: '1',
        subsystem: 'sbsTest',
        system: 'sysTest',
        type: 'COBOL',
    };
    const qualifier2 = {
        element: testElements[1].elmName,
        env: 'envTest',
        stage: '1',
        subsystem: 'sbsTest',
        system: 'sysTest',
        type: 'COBOL',
    };
    const testEndevorElementNodes = [
        new EndevorNodes_1.EndevorElementNode(testElements[0], qualifier1),
        new EndevorNodes_1.EndevorElementNode(testElements[1], qualifier2),
    ];
    // All spies are listed here
    const openDocumentSpy = jest.spyOn(vscode.workspace, 'openTextDocument');
    const retrieveElementErrorSpy = jest.spyOn(testRetrieveEltService, 'processRetrieveElementError');
    const loggerErrorSpy = jest.spyOn(globals_1.logger, 'error');
    beforeEach(() => {
        // Redefine mocks, because we clear them after each run
        mockWithProgress.mockImplementation((progLocation, callback) => __awaiter(void 0, void 0, void 0, function* () {
            const ProgressLocation = {
                Notification: 15,
                report: jest.fn(),
            };
            return yield callback(ProgressLocation);
        }));
        testDependencies[0].components = [testIElements[0]];
        mockRetrieveElement.mockReturnValue('test/elt/path');
        mockQueryACMComponents.mockReturnValue({ data: testDependencies });
    });
    afterEach(() => {
        // This is here to clear the spies
        jest.clearAllMocks();
    });
    test("Should preview an element's single dependency in the text editor (happy path)", () => __awaiter(void 0, void 0, void 0, function* () {
        yield RetrieveElementWithDependencies_1.retrieveWithDependencies(testEndevorElementNodes[0], testRetrieveEltService);
        expect(openDocumentSpy).toBeCalledWith('test/elt/path');
    }));
    test('Should cancel dependency download, when there are many dependencies and user decides to cancel', () => __awaiter(void 0, void 0, void 0, function* () {
        // Create a giant array of dependencies
        for (let i = 0; i < 21; ++i) {
            testDependencies[0].components.push(testIElements[0]);
        }
        // Mock vscode's warning function
        const mockShowWarningMessage = jest.fn();
        mockShowWarningMessage.mockResolvedValue('Cancel');
        Object.defineProperty(vscode.window, 'showWarningMessage', {
            value: mockShowWarningMessage,
        });
        yield RetrieveElementWithDependencies_1.retrieveWithDependencies(testEndevorElementNodes[0], testRetrieveEltService);
        expect(openDocumentSpy).toBeCalledTimes(0);
    }));
    test('Should retrieve dependencies of passed arg, if no element is fetched by retrieveElementService', () => __awaiter(void 0, void 0, void 0, function* () {
        mockQueryACMComponents.mockReturnValueOnce({ data: [] });
        yield RetrieveElementWithDependencies_1.retrieveWithDependencies(testEndevorElementNodes[0], testRetrieveEltService);
        expect(openDocumentSpy).toBeCalledWith('test/elt/path');
    }));
    test('Should throw an error, if element cannot be retrieved from Endevor', () => __awaiter(void 0, void 0, void 0, function* () {
        mockRetrieveElement.mockRejectedValueOnce('test error!');
        yield RetrieveElementWithDependencies_1.retrieveWithDependencies(testEndevorElementNodes[0], testRetrieveEltService);
        expect(retrieveElementErrorSpy).toBeCalledWith('test error!');
    }));
    test('Should throw an error, if no folder is open in the workspace', () => __awaiter(void 0, void 0, void 0, function* () {
        mockWorkspaceFolders.pop();
        yield RetrieveElementWithDependencies_1.retrieveWithDependencies(testEndevorElementNodes[0], testRetrieveEltService);
        expect(loggerErrorSpy).toBeCalledWith('Specify workspace before retrieving elements');
    }));
});
//# sourceMappingURL=retrieveElementWithDependencies-test.js.map