"use strict";
/* eslint-disable @typescript-eslint/no-explicit-any */
/* eslint-disable @typescript-eslint/no-non-null-assertion */
/*
 * Copyright (c) 2020 Broadcom.
 * The term "Broadcom" refers to Broadcom Inc. and/or its subsidiaries.
 *
 * This program and the accompanying materials are made
 * available under the terms of the Eclipse Public License 2.0
 * which is available at https://www.eclipse.org/legal/epl-2.0/
 *
 * SPDX-License-Identifier: EPL-2.0
 *
 * Contributors:
 *   Broadcom, Inc. - initial API and implementation
 */
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.HostDialogs = void 0;
const url_1 = require("url");
// import { ProgressLocation, window, workspace } from 'vscode';
const EndevorController_1 = require("../EndevorController");
const Repository_1 = require("../model/Repository");
const EndevorCliProxy_1 = require("../service/EndevorCliProxy");
const Profiles_1 = require("../service/Profiles");
const utils = require("../utils");
const vscode = require("vscode");
const Connection_1 = require("../model/Connection");
const globals_1 = require("../globals");
class HostDialogs {
    static addConnection() {
        return __awaiter(this, void 0, void 0, function* () {
            const allProfiles = Profiles_1.Profiles.getInstance().allProfiles;
            const createNewProfile = 'Create a New Endevor Profile';
            let chosenProfile;
            let profileNamesList = allProfiles.map((profile) => {
                return profile.name;
            });
            if (profileNamesList) {
                profileNamesList = profileNamesList.filter((profileNames) => !EndevorController_1.EndevorController.instance
                    .getConnections()
                    .find((connection) => connection.getName() === profileNames));
            }
            const createPick = new utils.FilterDescriptor('\uFF0B ' + createNewProfile);
            const items = profileNamesList.map((element) => new utils.FilterItem(element));
            const placeholder = 'Choose "Create new..." to define a new profile or select an existing one';
            const quickpick = vscode.window.createQuickPick();
            quickpick.items = [createPick, ...items];
            quickpick.placeholder = placeholder;
            quickpick.ignoreFocusOut = true;
            quickpick.show();
            const choice = yield utils.resolveQuickPickHelper(quickpick);
            quickpick.hide();
            if (!choice) {
                globals_1.logger.info('No selection made.');
                return;
            }
            if (choice instanceof utils.FilterDescriptor) {
                chosenProfile = '';
            }
            else {
                chosenProfile = choice.label;
            }
            if (chosenProfile === '') {
                let newProfileName;
                const options = {
                    placeHolder: 'Profile Name',
                    prompt: 'Enter a name for the profile',
                };
                const profileName = yield vscode.window.showInputBox(options);
                if (!profileName) {
                    globals_1.logger.info('Profile Name was not supplied. Operation Cancelled');
                    return;
                }
                chosenProfile = profileName;
                try {
                    newProfileName = yield Profiles_1.Profiles.getInstance().createNewConnection(chosenProfile);
                }
                catch (error) {
                    globals_1.logger.error(error.message);
                }
                if (newProfileName) {
                    try {
                        const newProfile = Profiles_1.Profiles.getInstance()
                            .listProfiles()
                            .find((profile) => profile.name === newProfileName);
                        if (newProfile) {
                            const profileToAdd = new Connection_1.Connection(newProfile);
                            EndevorController_1.EndevorController.instance.addConnection(profileToAdd);
                            EndevorController_1.EndevorController.instance.updateSettings();
                        }
                    }
                    catch (error) {
                        globals_1.logger.error('Error while adding new profile');
                    }
                }
            }
            else if (chosenProfile) {
                const profileToUse = allProfiles.find((profile) => profile.name === chosenProfile);
                if (profileToUse) {
                    const profileToAdd = new Connection_1.Connection(profileToUse);
                    EndevorController_1.EndevorController.instance.addConnection(profileToAdd);
                    EndevorController_1.EndevorController.instance.updateSettings();
                }
            }
            else {
                globals_1.logger.info('Operation cancelled');
            }
        });
    }
    /**
     * Add host.
     * @param
     * @returns
     */
    static addHost(connection) {
        return __awaiter(this, void 0, void 0, function* () {
            if (!(vscode.workspace.workspaceFolders &&
                vscode.workspace.workspaceFolders.length > 0)) {
                globals_1.logger.error('Specify workspace before creating repository.');
                return;
            }
            const profile = connection.getEntity().getProfile();
            const url = `${profile.protocol}://${profile.host}:${profile.port}`;
            // TODO: add dataSource here when we import endevor-connection profile
            const dataSource = '';
            const newRepo = new Repository_1.Repository('', url, profile.user, profile.password, dataSource, connection.label);
            vscode.window.withProgress({
                location: vscode.ProgressLocation.Notification,
            }, (progress) => __awaiter(this, void 0, void 0, function* () {
                progress.report({
                    message: 'Waiting for ' + newRepo.getUrl() + ' to respond.',
                    increment: 10,
                });
                try {
                    const dsNames = yield EndevorCliProxy_1.proxyGetDsNamesFromInstance(newRepo);
                    progress.report({ increment: 100 });
                    const dsItem = yield vscode.window.showQuickPick(dsNames.map((label) => ({ label })), {
                        ignoreFocusOut: true,
                    });
                    if (dsItem === undefined) {
                        return;
                    }
                    if (EndevorController_1.EndevorController.instance.isRepoInConnection(dsItem.label, connection.label)) {
                        globals_1.logger.warn('Configuration already exits.', `Configuration with name ${dsItem.label} already exits in this session.`);
                        return;
                    }
                    newRepo.setName(dsItem.label);
                    newRepo.setDatasource(dsItem.label);
                    EndevorController_1.EndevorController.instance.addRepository(newRepo, connection.getEntity().getName());
                    EndevorController_1.EndevorController.instance.updateSettings();
                    globals_1.logger.trace(`Configuration ${dsItem.label} was added.`);
                }
                catch (error) {
                    globals_1.logger.error('Host unreachable.', `Host ${newRepo.getUrl()} is not available.`);
                }
            }));
        });
    }
    static editHost(context) {
        return __awaiter(this, void 0, void 0, function* () {
            const repo = context.getRepository();
            if (repo) {
                const newName = yield HostDialogs.showHostNameInput(repo);
                const profileLabel = repo.getProfileLabel() ? repo.getProfileLabel() : '';
                if (newName === undefined) {
                    return;
                }
                if (EndevorController_1.EndevorController.instance.isRepoInConnection(newName, profileLabel)) {
                    globals_1.logger.warn('Configuration already exits', `Configuration with name ${newName} already exists`);
                    return;
                }
                const oldName = repo.getName();
                EndevorController_1.EndevorController.instance.updateRepositoryName(oldName, newName, profileLabel);
                EndevorController_1.EndevorController.instance.updateSettings();
                globals_1.logger.info('Configuration renamed.', `Configuration ${oldName} was renamed to ${newName}.`);
            }
        });
    }
    static showHostNameInput(repo) {
        return __awaiter(this, void 0, void 0, function* () {
            return vscode.window.showInputBox({
                ignoreFocusOut: true,
                placeHolder: 'Configuration name',
                prompt: 'Enter a custom name for the configuration.',
                validateInput: (text) => text !== '' ? '' : 'Please use only characters A-z and 0-9.',
                value: repo.getName(),
            });
        });
    }
    static showUrlInput() {
        return __awaiter(this, void 0, void 0, function* () {
            const validateUrl = (newUrl) => {
                let url;
                try {
                    url = new url_1.URL(newUrl);
                }
                catch (error) {
                    return false;
                }
                return url.port ? true : false;
            };
            return vscode.window.showInputBox({
                ignoreFocusOut: true,
                placeHolder: 'URL',
                prompt: "Enter a z/OS URL in the format 'http(s)://url:port'.",
                validateInput: (text) => validateUrl(text) ? '' : 'Please enter a valid URL.',
            });
        });
    }
}
exports.HostDialogs = HostDialogs;
//# sourceMappingURL=HostDialogs.js.map