"use strict";
/*
 * Copyright (c) 2020 Broadcom.
 * The term "Broadcom" refers to Broadcom Inc. and/or its subsidiaries.
 *
 * This program and the accompanying materials are made
 * available under the terms of the Eclipse Public License 2.0
 * which is available at https://www.eclipse.org/legal/epl-2.0/
 *
 * SPDX-License-Identifier: EPL-2.0
 *
 * Contributors:
 *   Broadcom, Inc. - initial API and implementation
 */
Object.defineProperty(exports, "__esModule", { value: true });
exports.EndevorFilter = exports.FILTER_ALL_STRING = void 0;
const EndevorEntity_1 = require("./EndevorEntity");
const constants = require("../constants");
exports.FILTER_ALL_STRING = '*/*/*/*/*/*';
class EndevorFilter extends EndevorEntity_1.EndevorEntity {
    constructor(repository, filterString) {
        super();
        this.repository = repository;
        this._envFilter = constants.ASTERISK;
        this._stageFilter = constants.ASTERISK;
        this._systemFilter = constants.ASTERISK;
        this._subsysFilter = constants.ASTERISK;
        this._typeFilter = constants.ASTERISK;
        this._elementFilter = constants.ASTERISK;
        this.elements = [];
        this.updateFilterString(filterString);
    }
    loadElements(newElements, append) {
        if (!append) {
            this.elements = [];
        }
        newElements.forEach((element) => {
            this.elements.push(element);
        });
    }
    getName() {
        if (this.filterAll()) {
            return 'Map';
        }
        return this.getUri();
    }
    getUri() {
        return (this._envFilter +
            '/' +
            this._stageFilter +
            '/' +
            this._systemFilter +
            '/' +
            this._subsysFilter +
            '/' +
            this._typeFilter +
            '/' +
            this._elementFilter);
    }
    getDescription() {
        return '';
    }
    getRepository() {
        return this.repository;
    }
    setRepository(value) {
        this.repository = value;
    }
    getElements() {
        return this.elements;
    }
    getQualifier() {
        return {
            env: this._envFilter,
            stage: this._stageFilter,
            system: this._systemFilter,
            subsystem: this._subsysFilter,
            type: this._typeFilter,
            element: this._elementFilter,
        };
    }
    filterAll() {
        if (this._envFilter !== constants.ASTERISK) {
            return false;
        }
        if (this._stageFilter !== constants.ASTERISK) {
            return false;
        }
        if (this._systemFilter !== constants.ASTERISK) {
            return false;
        }
        if (this._subsysFilter !== constants.ASTERISK) {
            return false;
        }
        if (this._typeFilter !== constants.ASTERISK) {
            return false;
        }
        if (this._elementFilter !== constants.ASTERISK) {
            return false;
        }
        return true;
    }
    updateFilterString(filterString) {
        const filterTokens = filterString.split('/');
        if (filterTokens.length !== 6) {
            throw new Error('Filter string is invalid!');
        }
        this._envFilter = filterTokens[0];
        this._stageFilter = filterTokens[1];
        this._systemFilter = filterTokens[2];
        this._subsysFilter = filterTokens[3];
        this._typeFilter = filterTokens[4];
        this._elementFilter = filterTokens[5];
    }
    editFilter(name) {
        const filters = this.getRepository().filters;
        const index = filters.indexOf(this);
        if (index >= 0) {
            filters[index].updateFilterString(name);
        }
    }
    deleteFilter() {
        const filters = this.getRepository().filters;
        const index = filters.indexOf(this);
        if (index >= 0) {
            filters.splice(index, 1);
        }
    }
    get envFilter() {
        return this._envFilter;
    }
    set envFilter(value) {
        this._envFilter = value;
    }
    get stageFilter() {
        return this._stageFilter;
    }
    set stageFilter(value) {
        this._stageFilter = value;
    }
    get systemFilter() {
        return this._systemFilter;
    }
    set systemFilter(value) {
        this._systemFilter = value;
    }
    get subsysFilter() {
        return this._subsysFilter;
    }
    set subsysFilter(value) {
        this._subsysFilter = value;
    }
    get typeFilter() {
        return this._typeFilter;
    }
    set typeFilter(value) {
        this._typeFilter = value;
    }
    get elementFilter() {
        return this._elementFilter;
    }
    set elementFilter(value) {
        this._elementFilter = value;
    }
}
exports.EndevorFilter = EndevorFilter;
//# sourceMappingURL=EndevorFilter.js.map