"use strict";
/*
 * Copyright (c) 2020 Broadcom.
 * The term "Broadcom" refers to Broadcom Inc. and/or its subsidiaries.
 *
 * This program and the accompanying materials are made
 * available under the terms of the Eclipse Public License 2.0
 * which is available at https://www.eclipse.org/legal/epl-2.0/
 *
 * SPDX-License-Identifier: EPL-2.0
 *
 * Contributors:
 *   Broadcom, Inc. - initial API and implementation
 */
Object.defineProperty(exports, "__esModule", { value: true });
exports.Environment = void 0;
const EndevorEntity_1 = require("./EndevorEntity");
class Environment extends EndevorEntity_1.EndevorEntity {
    constructor(repository, env) {
        super();
        this.repository = repository;
        this.envName = env.envName;
        this.systems = new Map();
        this.stages = new Array(2);
    }
    loadSystems(newSystems, append) {
        if (!append) {
            this.systems = new Map();
        }
        newSystems.forEach((sys) => {
            this.systems.set(sys.sysName, sys);
        });
    }
    loadStages(newStages) {
        if (newStages.length !== 2) {
            throw Error('Incorrect number of stages');
        }
        this.stages[0] = newStages[0];
        this.stages[1] = newStages[1];
    }
    getName() {
        return this.envName;
    }
    getDescription() {
        return '';
    }
    getEnvName() {
        return this.envName;
    }
    getRepository() {
        return this.repository;
    }
    findSystem(sysName) {
        return this.systems.get(sysName);
    }
    getSystems() {
        return Array.from(this.systems.values());
    }
    getStage(num) {
        return this.stages[num];
    }
    getStages() {
        return this.stages;
    }
}
exports.Environment = Environment;
//# sourceMappingURL=Environment.js.map