"use strict";
/*
 * Copyright (c) 2020 Broadcom.
 * The term "Broadcom" refers to Broadcom Inc. and/or its subsidiaries.
 *
 * This program and the accompanying materials are made
 * available under the terms of the Eclipse Public License 2.0
 * which is available at https://www.eclipse.org/legal/epl-2.0/
 *
 * SPDX-License-Identifier: EPL-2.0
 *
 * Contributors:
 *   Broadcom, Inc. - initial API and implementation
 */
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.RetrieveElementService = void 0;
const fs = require("fs");
const path = require("path");
const Element_1 = require("../model/Element");
const EndevorCliProxy_1 = require("./EndevorCliProxy");
const globals_1 = require("../globals");
class RetrieveElementService {
    // eslint-disable-next-line @typescript-eslint/no-empty-function
    constructor() { }
    retrieveElement(workspace, repo, elementName, eq) {
        return __awaiter(this, void 0, void 0, function* () {
            const data = yield EndevorCliProxy_1.proxyRetrieveElement(repo, eq);
            const ext = yield this.getExtension(repo, eq);
            const type = eq.type ? eq.type : '';
            const typeDirectory = path.join(workspace.uri.fsPath, type);
            if (!fs.existsSync(typeDirectory)) {
                fs.mkdirSync(typeDirectory);
            }
            const filePath = path.join(typeDirectory, elementName + (ext ? '.' + ext : ''));
            // eslint-disable-next-line @typescript-eslint/no-non-null-assertion
            fs.writeFileSync(filePath, data);
            return filePath;
        });
    }
    // eslint-disable-next-line @typescript-eslint/no-explicit-any
    processRetrieveElementError(error) {
        return __awaiter(this, void 0, void 0, function* () {
            if (!error.cancelled) {
                globals_1.logger.error('Error retrieving elements.', error.error);
            }
        });
    }
    /**
     * List dependencies
     * @returns list of dependencies with origin element. Origin element always first.
     */
    retrieveDependenciesList(repo, eq) {
        return __awaiter(this, void 0, void 0, function* () {
            const result = [];
            const elements = yield EndevorCliProxy_1.proxyRetrieveAcmComponents(repo, eq);
            if (elements.length === 0) {
                return [];
            }
            const el = elements[0];
            result.push(new Element_1.Element(repo, el));
            if (Object.getOwnPropertyDescriptor(el, 'components')) {
                for (const dep of el['components']) {
                    if (dep.elmName.trim()) {
                        const element = new Element_1.Element(repo, dep);
                        result.push(element);
                    }
                }
            }
            return result;
        });
    }
    getExtension(repo, eq) {
        return __awaiter(this, void 0, void 0, function* () {
            const types = yield EndevorCliProxy_1.proxyListType(repo, eq);
            for (const type of types) {
                if (type.typeName === eq.type && type.fileExt) {
                    return type.fileExt;
                }
            }
            globals_1.logger.trace(`No fileExt information in element type ${eq.type} for ${eq.element}. Type name will be used.`);
            // eslint-disable-next-line @typescript-eslint/consistent-type-assertions
            return eq.type.toLowerCase();
        });
    }
}
exports.RetrieveElementService = RetrieveElementService;
//# sourceMappingURL=RetrieveElementService.js.map