"use strict";
/* eslint-disable @typescript-eslint/consistent-type-assertions */
/*
 * Copyright (c) 2020 Broadcom.
 * The term "Broadcom" refers to Broadcom Inc. and/or its subsidiaries.
 *
 * This program and the accompanying materials are made
 * available under the terms of the Eclipse Public License 2.0
 * which is available at https://www.eclipse.org/legal/epl-2.0/
 *
 * SPDX-License-Identifier: EPL-2.0
 *
 * Contributors:
 *   Broadcom, Inc. - initial API and implementation
 */
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.NewRepositoryNode = exports.NewConnectionButton = exports.ConnectionNode = exports.TypeNode = exports.SubsystemNode = exports.SystemNode = exports.StageNode = exports.EnvironmentNode = exports.EndevorElementNode = exports.EndevorQualifiedNode = exports.FilterNode = exports.EmptyNode = exports.EndevorFilterPathNode = exports.EndevorBrowsingNode = exports.EndevorNode = void 0;
// eslint-disable-next-line @typescript-eslint/ban-ts-comment
// @ts-nocheck
const vscode = require("vscode");
const FilterUtils_1 = require("../../FilterUtils");
const Element_1 = require("../../model/Element");
const Connection_1 = require("../../model/Connection");
const EndevorFilter_1 = require("../../model/EndevorFilter");
const Environment_1 = require("../../model/Environment");
const Repository_1 = require("../../model/Repository");
const Stage_1 = require("../../model/Stage");
const SubSystem_1 = require("../../model/SubSystem");
const System_1 = require("../../model/System");
const Type_1 = require("../../model/Type");
const EndevorCliProxy_1 = require("../../service/EndevorCliProxy");
const globals_1 = require("../../globals");
class EndevorNode extends vscode.TreeItem {
    constructor(entity) {
        const entityName = entity ? entity.getName() : 'unknown';
        // eslint-disable-next-line @typescript-eslint/no-non-null-assertion
        super(entityName, vscode.TreeItemCollapsibleState.Collapsed);
        this._needReload = true;
        this.description = '';
        this._children = [];
        if (entity instanceof Element_1.Element) {
            this.collapsibleState = vscode.TreeItemCollapsibleState.None;
        }
        if (entity) {
            this.entity = entity;
            this.tooltip = entity.getDescription()
                ? entity.getDescription()
                : entity.getName();
        }
    }
    hasChildren() {
        return this._children.length > 0;
    }
    get children() {
        return this._children;
    }
    set children(value) {
        this._children = value;
    }
    get needReload() {
        return this._needReload;
    }
    set needReload(value) {
        this._needReload = value;
    }
    getEntity() {
        return this.entity;
    }
    setEntity(value) {
        this.entity = value;
    }
    getRepository() {
        if (this.entity) {
            return this.entity.getRepository();
        }
    }
    get contextValue() {
        if (!this.entity) {
            return '';
        }
        if (this.entity instanceof Repository_1.Repository) {
            return 'repository';
        }
        if (this.entity instanceof EndevorFilter_1.EndevorFilter) {
            return 'filter';
        }
        if (this.entity instanceof Environment_1.Environment) {
            return 'environment';
        }
        if (this.entity instanceof Stage_1.Stage) {
            return 'stage';
        }
        if (this.entity instanceof System_1.System) {
            return 'system';
        }
        if (this.entity instanceof SubSystem_1.SubSystem) {
            return 'subsystem';
        }
        if (this.entity instanceof Type_1.Type) {
            return 'type';
        }
        if (this.entity instanceof Connection_1.Connection) {
            return 'connection';
        }
        return 'element';
    }
    updateNeedReload(parNeedReload) {
        this._needReload = parNeedReload;
        this._children.forEach((child) => {
            child.updateNeedReload(parNeedReload);
        });
    }
    updateInfo() {
        this.tooltip = this.entity ? this.entity.getDescription() : '';
        this.label = this.entity ? this.entity.getName() : '';
    }
}
exports.EndevorNode = EndevorNode;
class EndevorBrowsingNode extends EndevorNode {
    constructor(name, repo) {
        super();
        this.label = name;
        this.repository = repo;
    }
    get contextValue() {
        if (this.isFiltersNode()) {
            return 'filters';
        }
        if (this.isMapNode()) {
            return 'map';
        }
        return super.contextValue;
    }
    isMapNode() {
        return this.label === 'Map';
    }
    isFiltersNode() {
        return this.label === 'Filters';
    }
    findFilterNode(filter) {
        if (this.isMapNode()) {
            return undefined;
        }
        let uri = '';
        if (filter instanceof EndevorFilter_1.EndevorFilter) {
            uri = filter.getUri();
        }
        else {
            uri = filter;
        }
        return this.children.find(
        // eslint-disable-next-line @typescript-eslint/consistent-type-assertions
        (child) => child.getEntity().getUri() === uri);
    }
    getRepository() {
        return this.repository;
    }
    lazyLoadChildren() {
        return __awaiter(this, void 0, void 0, function* () {
            const repo = this.getRepository();
            if (!repo) {
                return Promise.resolve([]);
            }
            if (!this.needReload) {
                return Promise.resolve(this.children);
            }
            this.needReload = false;
            if (this.contextValue === 'filters') {
                return new Promise((resolve) => {
                    const resultNodes = [];
                    if (repo.filters) {
                        repo.filters.forEach((filter) => {
                            resultNodes.push(new FilterNode(filter));
                        });
                    }
                    this.children = resultNodes;
                    resolve(resultNodes);
                });
            }
            try {
                const resultNodes = [];
                const resultEntities = [];
                const envs = yield EndevorCliProxy_1.proxyListEnvironment(repo);
                envs.forEach((env) => {
                    const envEntity = new Environment_1.Environment(repo, env);
                    resultEntities.push(envEntity);
                    resultNodes.push(new EnvironmentNode(envEntity, { env: env.envName }));
                });
                repo.loadEnvironments(resultEntities, true);
                this.children = resultNodes;
                return resultNodes;
            }
            catch (error) {
                if (!error.cancelled) {
                    globals_1.logger.error('Error creating the root tree.', error.error);
                }
                return [];
            }
        });
    }
}
exports.EndevorBrowsingNode = EndevorBrowsingNode;
class EndevorFilterPathNode extends EndevorNode {
    constructor(name, repo, elements) {
        super();
        this.elements = elements;
        this.label = name;
        this.repository = repo;
    }
    lazyLoadChildren() {
        const repo = this.getRepository();
        if (!repo) {
            return Promise.resolve([]);
        }
        if (!this.needReload) {
            return Promise.resolve(this.children);
        }
        const resultNodes = [];
        this.getElements().forEach((element) => {
            const qualifier = {
                env: element.envName,
                stage: element.stgNum,
                system: element.sysName,
                subsystem: element.sbsName,
                type: element.typeName,
                element: element.fullElmName,
            };
            resultNodes.push(new EndevorQualifiedNode(element, qualifier));
        });
        this.children = resultNodes;
        this.needReload = false;
        return Promise.resolve(resultNodes);
    }
    getElements() {
        return this.elements;
    }
    getRepository() {
        return this.repository;
    }
    get contextValue() {
        return 'filterPathNode';
    }
}
exports.EndevorFilterPathNode = EndevorFilterPathNode;
class EmptyNode extends EndevorNode {
    constructor(name, repo, message) {
        super();
        this.label = name;
        this.repository = repo;
        this.message = message;
        this.tooltip = this.getMessage();
    }
    getMessage() {
        return this.message;
    }
    getRepository() {
        return this.repository;
    }
    get contextValue() {
        return 'emptyNode';
    }
}
exports.EmptyNode = EmptyNode;
class FilterNode extends EndevorNode {
    lazyLoadChildren() {
        return __awaiter(this, void 0, void 0, function* () {
            const repo = this.getRepository();
            const filterEntity = this.getEntity();
            const qualifier = filterEntity.getQualifier();
            if (!filterEntity || !qualifier || !repo) {
                return Promise.resolve([]);
            }
            if (!this.needReload) {
                return Promise.resolve(this.children);
            }
            this.needReload = false;
            try {
                const elements = yield EndevorCliProxy_1.proxyListElement(repo, qualifier);
                const resultEntities = [];
                let resultNodes = [];
                for (const element of elements) {
                    const eleEntity = new Element_1.Element(repo, element);
                    resultEntities.push(eleEntity);
                    resultNodes.push(new EndevorElementNode(eleEntity, eleEntity.getQualifier()));
                }
                filterEntity.loadElements(resultEntities, false);
                const pathNodes = FilterUtils_1.createPathNodes(resultEntities, repo);
                if (pathNodes.length > 1) {
                    resultNodes = pathNodes;
                }
                if (resultNodes.length === 0) {
                    resultNodes = [
                        FilterUtils_1.createEmptyNode(repo, '<Empty>', 'This filter is empty'),
                    ];
                }
                this.children = resultNodes;
                return resultNodes;
            }
            catch (error) {
                if (!error.cancelled) {
                    globals_1.logger.error('Error listing filters.', error.error);
                }
                const resultNodes = [
                    FilterUtils_1.createEmptyNode(repo, '<Invalid Path>', error.error),
                ];
                this.children = resultNodes;
                return resultNodes;
            }
        });
    }
}
exports.FilterNode = FilterNode;
class EndevorQualifiedNode extends EndevorNode {
    constructor(entity, qualifier) {
        super(entity);
        this.qualifier = qualifier;
    }
    getQualifier() {
        return this.qualifier;
    }
}
exports.EndevorQualifiedNode = EndevorQualifiedNode;
class EndevorElementNode extends EndevorNode {
    constructor(entity, qualifier) {
        super(entity);
        this.qualifier = qualifier;
    }
    getQualifier() {
        return this.qualifier;
    }
}
exports.EndevorElementNode = EndevorElementNode;
class EnvironmentNode extends EndevorQualifiedNode {
    lazyLoadChildren() {
        return __awaiter(this, void 0, void 0, function* () {
            const repo = this.getRepository();
            const envEntity = this.getEntity();
            const nodeQualEnv = this.getQualifier();
            if (!envEntity || !nodeQualEnv || !repo) {
                return Promise.resolve([]);
            }
            if (!this.needReload) {
                return Promise.resolve(this.children);
            }
            this.needReload = false;
            try {
                const stages = yield EndevorCliProxy_1.proxyListStage(repo, nodeQualEnv);
                const resultEntities = [];
                const resultNodes = [];
                stages.forEach((stage) => {
                    const stageEntity = new Stage_1.Stage(repo, stage);
                    resultEntities.push(stageEntity);
                    resultNodes.push(new StageNode(stageEntity, Object.assign(Object.assign({}, nodeQualEnv), { stage: stage.stgNum })));
                });
                envEntity.loadStages(resultEntities);
                this.children = resultNodes;
                return resultNodes;
            }
            catch (error) {
                if (!error.cancelled) {
                    globals_1.logger.error('Error listing environments.', error.error);
                }
                return [];
            }
        });
    }
}
exports.EnvironmentNode = EnvironmentNode;
class StageNode extends EndevorQualifiedNode {
    lazyLoadChildren() {
        return __awaiter(this, void 0, void 0, function* () {
            const repo = this.getRepository();
            const stageEntity = this.getEntity();
            const nodeQualStage = this.getQualifier();
            if (!stageEntity || !nodeQualStage || !repo) {
                return Promise.resolve([]);
            }
            if (!this.needReload) {
                return Promise.resolve(this.children);
            }
            this.needReload = false;
            try {
                const resultEntities = [];
                const resultNodes = [];
                const systems = yield EndevorCliProxy_1.proxyListSystem(repo, nodeQualStage);
                systems.forEach((system) => {
                    const systemEntity = new System_1.System(repo, system);
                    resultEntities.push(systemEntity);
                    resultNodes.push(new SystemNode(systemEntity, Object.assign(Object.assign({}, nodeQualStage), { system: system.sysName })));
                });
                const env = repo.findEnvironment(stageEntity.envName);
                if (env) {
                    env.loadSystems(resultEntities, true);
                }
                this.children = resultNodes;
                return resultNodes;
            }
            catch (error) {
                if (!error.cancelled) {
                    globals_1.logger.error('Error listing stages.', error.error);
                }
                return [];
            }
        });
    }
}
exports.StageNode = StageNode;
class SystemNode extends EndevorQualifiedNode {
    lazyLoadChildren() {
        return __awaiter(this, void 0, void 0, function* () {
            const repo = this.getRepository();
            const systemEntity = this.getEntity();
            const nodeQualSystem = this.getQualifier();
            if (!systemEntity || !nodeQualSystem || !repo) {
                return Promise.resolve([]);
            }
            if (!this.needReload) {
                return Promise.resolve(this.children);
            }
            this.needReload = false;
            try {
                const resultEntities = [];
                const resultNodes = [];
                const subsystems = yield EndevorCliProxy_1.proxyListSubsystem(repo, nodeQualSystem);
                subsystems.forEach((subsystem) => {
                    const subsysEntity = new SubSystem_1.SubSystem(repo, subsystem);
                    resultEntities.push(subsysEntity);
                    resultNodes.push(new SubsystemNode(subsysEntity, Object.assign(Object.assign({}, nodeQualSystem), { subsystem: subsystem.sbsName })));
                });
                systemEntity.loadSubSystems(resultEntities, true);
                this.children = resultNodes;
                return resultNodes;
            }
            catch (error) {
                if (!error.cancelled) {
                    globals_1.logger.error('Error listing systems.', error.error);
                }
                return [];
            }
        });
    }
}
exports.SystemNode = SystemNode;
class SubsystemNode extends EndevorQualifiedNode {
    lazyLoadChildren() {
        return __awaiter(this, void 0, void 0, function* () {
            const repo = this.getRepository();
            const subsysEntity = this.getEntity();
            const nodeQualSubsys = this.getQualifier();
            if (!subsysEntity || !nodeQualSubsys || !repo) {
                return Promise.resolve([]);
            }
            if (!this.needReload) {
                return Promise.resolve(this.children);
            }
            this.needReload = false;
            try {
                const resultEntities = [];
                const resultNodes = [];
                const types = yield EndevorCliProxy_1.proxyListType(repo, nodeQualSubsys);
                types.forEach((type) => {
                    const typeEntity = new Type_1.Type(repo, type);
                    resultEntities.push(typeEntity);
                    resultNodes.push(new TypeNode(typeEntity, Object.assign(Object.assign({}, nodeQualSubsys), { type: type.typeName })));
                });
                const system = repo.findSystem(subsysEntity.envName, subsysEntity.sysName);
                if (system) {
                    system.loadTypes(resultEntities, true);
                }
                this.children = resultNodes;
                return resultNodes;
            }
            catch (error) {
                if (!error.cancelled) {
                    globals_1.logger.error('Error listing subsystems.', error.error);
                }
                return [];
            }
        });
    }
}
exports.SubsystemNode = SubsystemNode;
class TypeNode extends EndevorQualifiedNode {
    lazyLoadChildren() {
        return __awaiter(this, void 0, void 0, function* () {
            const repo = this.getRepository();
            const nodeQualType = this.getQualifier();
            if (!nodeQualType || !repo) {
                return Promise.resolve([]);
            }
            if (!this.needReload) {
                return Promise.resolve(this.children);
            }
            this.needReload = false;
            try {
                const resultNodes = [];
                const elements = yield EndevorCliProxy_1.proxyListElement(repo, nodeQualType);
                elements.forEach((element) => {
                    const eleEntity = new Element_1.Element(repo, element);
                    resultNodes.push(new EndevorElementNode(eleEntity, Object.assign(Object.assign({}, nodeQualType), { element: element.fullElmName })));
                });
                if (resultNodes.length === 0) {
                    resultNodes.push(FilterUtils_1.createEmptyNode(repo, '<Empty>', 'This Type is empty'));
                }
                this.children = resultNodes;
                return resultNodes;
            }
            catch (error) {
                if (!error.cancelled) {
                    globals_1.logger.error('Error listing types.', error.error);
                }
                return [];
            }
        });
    }
}
exports.TypeNode = TypeNode;
class ConnectionNode extends EndevorNode {
    constructor(session, label, connection) {
        super();
        this._session = undefined;
        this._connection = undefined;
        this._connectionName = undefined;
        if (session) {
            this._session = session;
        }
        if (label) {
            this._connectionName = label;
        }
        if (connection) {
            this._connection = connection;
        }
    }
    getProfileName() {
        return this._connectionName;
    }
    getConnection() {
        return this._connection;
    }
    getSession() {
        return this._session;
    }
    get contextValue() {
        return 'connection';
    }
}
exports.ConnectionNode = ConnectionNode;
class NewConnectionButton extends EndevorNode {
    constructor() {
        super();
        this.command = {
            command: 'endevorexplorer.newConnection',
            title: 'Add a New Profile',
        };
        // TODO remove if Theis fix naming (theia/packages/plugin-ext/src/main/browser/view/tree-views-main.tsx)
        // handleTreeEvents expect node.command.id with command id, but vscode - node.command.command
        // issue: https://github.com/theia-ide/theia/issues/5744
        // eslint-disable-next-line @typescript-eslint/ban-ts-comment
        // @ts-ignore
        this.command.id = 'endevorexplorer.newConnection';
        this.label = 'Add a New Profile';
        this.collapsibleState = vscode.TreeItemCollapsibleState.None;
    }
    get contextValue() {
        return 'connectionButton';
    }
}
exports.NewConnectionButton = NewConnectionButton;
class NewRepositoryNode extends EndevorNode {
    constructor() {
        super();
        this.command = {
            command: 'endevorexplorer.newHost',
            title: 'Create New Host',
        };
        // TODO remove if Theis fix naming (theia/packages/plugin-ext/src/main/browser/view/tree-views-main.tsx)
        // handleTreeEvents expect node.command.id with command id, but vscode - node.command.command
        // issue: https://github.com/theia-ide/theia/issues/5744
        // eslint-disable-next-line @typescript-eslint/ban-ts-comment
        // @ts-ignore
        this.command.id = 'endevorexplorer.newHost';
        this.label = 'Add a New Configuration';
        this.collapsibleState = vscode.TreeItemCollapsibleState.None;
    }
    get contextValue() {
        return 'newrepository';
    }
}
exports.NewRepositoryNode = NewRepositoryNode;
//# sourceMappingURL=EndevorNodes.js.map