"use strict";
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
Object.defineProperty(exports, "__esModule", { value: true });
const path = require("path");
const vscode_test_1 = require("vscode-test");
function main() {
    return __awaiter(this, void 0, void 0, function* () {
        try {
            // The folder containing the Extension Manifest package.json
            // Passed to `--extensionDevelopmentPath`
            const extensionDevelopmentPath = path.resolve(__dirname, '../');
            // The path to test runner
            // Passed to --extensionTestsPath
            const extensionTestsPath = path.resolve(__dirname, './suite/bootstrap');
            // Set grep value for Mocha, to trigger only the type of tests passed in package.json
            // format is `(type)`, where type = unit | integration | system
            // if no type is passed, ALL tests are executed
            const MOCHA_grep_value = process.argv.length > 2 ? `(${process.argv[2]})` : '';
            let testOptions;
            // Have to use insiders version if we want to run it from CLI as well (as opposed to Run from Activity Bar only)
            // See: https://code.visualstudio.com/api/working-with-extensions/testing-extension#tips
            if (process.argv.length > 2 && process.argv[2] == 'insiders') {
                const vscodeExecutablePath = yield vscode_test_1.downloadAndUnzipVSCode('insiders');
                testOptions = {
                    vscodeExecutablePath,
                    extensionDevelopmentPath,
                    extensionTestsPath,
                    launchArgs: ['--disable-extensions'],
                    extensionTestsEnv: {
                        MOCHA_grep: MOCHA_grep_value,
                    },
                };
            }
            else {
                testOptions = {
                    extensionDevelopmentPath,
                    extensionTestsPath,
                    launchArgs: ['--disable-extensions'],
                    extensionTestsEnv: {
                        MOCHA_grep: MOCHA_grep_value,
                    },
                };
            }
            // Download VS Code, unzip it and run the integration test
            yield vscode_test_1.runTests(testOptions);
        }
        catch (err) {
            console.error('Failed to run tests');
            process.exit(1);
        }
    });
}
main();
//# sourceMappingURL=runTest.js.map